import React, { useState } from "react";
import {
  useLazyAddToCartQuery,
  useLazyCartDataQuery,
} from "../../app/features/cart/apiSlice";
import useLanguage from "../../hooks/useLanguage";

function ProductWareHouse({ seller }) {
  const [addToCart, { data, isLoading, isFetching }] = useLazyAddToCartQuery();
  const [cartData] = useLazyCartDataQuery();
  const [qty, setQty] = useState(1);
  const language = useLanguage();
  return (
    <div className="w-full flex justify-between lg:items-center py-4 px-5 border-b border-[#F8EBFF]">
      <div>
        <p className=" text-base text-dark-300 font-medium capitalize mb-[2px] notranslate">
          {seller?.warehouse?.name}
        </p>
        <div className="text-sm flex lg:flex-row flex-col lg:gap-6">
          <p className="text-[#65656C]">
            {language["Warehouses"]} :{" "}
            <span className=" text-primary-200">{seller?.status}</span>
          </p>
          <p className="text-[#65656C]">
            {language["Available"]} :{" "}
            <span className=" text-primary-200">{seller?.stock} T</span>
          </p>
        </div>
      </div>
      <div className="">
        <p className=" text-sm  font-medium text-dark-300">
          {seller?.price}${" "}
          <span className=" text-primary-200 notranslate">
            {" "}
            / {language["Ton"]}
          </span>
        </p>
        <div className="flex flex-wrap w-fit justify-end gap-2 mt-[6px]">
          <div className="flex items-center max-w-[100px] text-sm gap-1 border rounded px-2 border-[#F8EBFF] overflow-hidden">
            <p className="text-sm text-dark-300 notranslate">
              {language["qty"]}:{" "}
            </p>
            <input
              type="number"
              value={qty}
              onChange={(e) => {
                setQty(e.target.value);
              }}
              className=" max-w-full h-8 bg-transparent border-none outline-none ring-0 focus:border-none focus:outline-none focus:ring-0 p-0 flex items-center"
              placeholder="qty"
            />
          </div>
          <button
            onClick={() =>
              addToCart({
                productId: seller.product_id,
                quantity: qty,
                warehouseId: seller.id,
                sellerId: seller.seller_id,
                updateCartData: cartData,
              })
            }
            className="cartBtn group"
          >
            <svg
              className="w-5 h-5"
              width="24"
              height="24"
              viewBox="0 0 24 24"
              fill="none"
              xmlns="http://www.w3.org/2000/svg"
            >
              <path
                className=" group-hover:stroke-white transition-all duration-500"
                d="M9 14L9 18"
                stroke="#001C31"
                strokeWidth="2"
                strokeLinecap="round"
                strokeLinejoin="round"
              />
              <path
                className=" group-hover:stroke-white transition-all duration-500"
                d="M15 14L15 18"
                stroke="#001C31"
                strokeWidth="2"
                strokeLinecap="round"
                strokeLinejoin="round"
              />
              <path
                d="M6 6V4C6 2.89543 6.89543 2 8 2H16C17.1046 2 18 2.89543 18 4V6"
                className=" group-hover:stroke-white transition-all duration-500"
                stroke="#001C31"
                strokeWidth="2"
                strokeLinecap="round"
                strokeLinejoin="round"
              />
              <path
                className=" group-hover:stroke-white transition-all duration-500"
                d="M2.58683 10H21.4132M18.0351 6L5.96486 6C3.45403 6 1.57594 8.32624 2.08312 10.808L3.71804 18.808C4.09787 20.6666 5.71942 22 7.59978 22H16.4002C18.2806 22 19.9021 20.6666 20.282 18.808L21.9169 10.808C22.4241 8.32624 20.546 6 18.0351 6Z"
                stroke="#001C31"
                strokeWidth="2"
                strokeLinecap="round"
                strokeLinejoin="round"
              />
            </svg>
          </button>
        </div>
      </div>
    </div>
  );
}

export default ProductWareHouse;
